Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Repository ¶
type Repository interface {
Create(docs []solr.Document, chunkSize int, params *url.Values) error
Select(key, value string) ([]solr.Document, error)
Delete(data map[string]interface{}, params *url.Values) error
}
Repository represent the repositories
func NewSolrRepository ¶
func NewSolrRepository(Client *solr.SolrInterface) Repository
NewSolrRepository will create an object that represent the Repository interface
type Service ¶
type Service interface {
Create(data form.UserForm) (int, error)
Select(key, value string) ([]map[string]interface{}, int, error)
Delete(id string) (int, error)
}
Service represent the services
func NewService ¶
func NewService(log *logrus.Entry, r Repository) Service
NewService will create an object that represent the Service interface
Click to show internal directories.
Click to hide internal directories.