config

package
v0.0.0-...-c3e5ec8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 14, 2020 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Configuration represent the variable of configuration model
	Configuration = &ConfigurationModel{}
)

Functions

func InitLog

func InitLog() *logrus.Entry

InitLog will create a variable that represent the logrus.Entry

func InitSolr

func InitSolr() (*solr.SolrInterface, error)

InitSolr will create a variable that represent the solr.SolrInterface

Types

type ConfigurationModel

type ConfigurationModel struct {
	Port string `json:"port"`
	Solr struct {
		Addr string `json:"addr"`
		Core string `json:"core"`
	} `json:"solr"`
}

ConfigurationModel represent the configuration model

Jump to