Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Configuration represent the variable of configuration model Configuration = &ConfigurationModel{} )
Functions ¶
func InitSolr ¶
func InitSolr() (*solr.SolrInterface, error)
InitSolr will create a variable that represent the solr.SolrInterface
Types ¶
type ConfigurationModel ¶
type ConfigurationModel struct {
Port string `json:"port"`
Solr struct {
Addr string `json:"addr"`
Core string `json:"core"`
} `json:"solr"`
}
ConfigurationModel represent the configuration model
Click to show internal directories.
Click to hide internal directories.